#!/usr/bin/env python
# -*- coding:utf-8 -*-


# ############################################################################
#  license :
# ============================================================================
#
#  File :        ArinaxBzoom.py
#
#  Project :     Arinax B-Zoom TangoVideoServer proxy
#
# This file is part of Tango device class.
# 
# Tango is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# Tango is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with Tango.  If not, see <http://www.gnu.org/licenses/>.
# 
#
#  $Author :      sci.comp$
#
#  $Revision :    $
#
#  $Date :        $
#
#  $HeadUrl :     $
# ============================================================================
#            This file is generated by POGO
#     (Program Obviously used to Generate tango Object)
# ############################################################################

__all__ = ["ArinaxBzoom", "ArinaxBzoomClass", "main"]

__docformat__ = 'restructuredtext'

import PyTango
import sys
# Add additional import
#----- PROTECTED REGION ID(ArinaxBzoom.additionnal_import) ENABLED START -----#
import traceback
import time
import struct
from PIL import Image
import numpy
import threading

#-----------------------------------------------------------------------------------
#    TangoClient
#-----------------------------------------------------------------------------------
class TangoClient():
    attributes = {'camera_name': None,
                  'camera_[*]_pixelsize': None,
                  'image_[*]_width': None,
                  'image_[*]_height': None,
                  'video_[*]_exposure': [2000, 50000, 22200],
                  'video_[*]_exposure_range': None,
                  'video_[*]_gain': [0.1, 0.2, 0.5],
                  'video_[*]_gain_range': None,
                  'video_[*]_scale': None,
                  'num_zoom_levels': None,
                  'video_zoom_idx': 5,
                  'video_zoom_percent': 0.6,
                  'video_predefined_zoom_list': None,
                  'video_zoom_list': None,
                  'video_[*]_mode': ['RGB8Packed', 'BayerBG8', 'BayerRG8'],
                  'video_[*]_white_balance': ['Continuous', 'Auto', 'Off'],
                  'video_[*]_white_balance_red': [0.1, 0.15, 0.5],
                  'video_[*]_white_balance_blue': [0.5, 0.2, 0.1],
                  'width_magnification_ratio': None,
                  'height_magnification_ratio': None,
                  'width_optic_center_offset': None,
                  'height_optic_center_offset': None,
                  'video_live': None,
                  'video_[*]_last_image_counter': None,
                  'video_[*]_fps': None,
                  'endianness': None}
    # ------------------
    header_format = '>IHHqiiHHHH'
    header_size = struct.calcsize(header_format)
    hybrid = 'bzoom'
    first = 'acA2500-x5'
    second = 'acA2440-x30'




#-----------------------------------------------------------------------------------
#    readThread
#-----------------------------------------------------------------------------------

class readThread(threading.Thread):

    def __init__(self, parent, device):
        threading.Thread.__init__(self)
        self.alive_ = True
        self.paused_ = True
        self.__parent = parent
        self.__device = device

#-----------------------------------------------------------------------------------
#    run
#-----------------------------------------------------------------------------------
    def run(self):
        THREAD_DELAY_SEC = 0.01
        # Enter a loop to read images
        tango_last_img_counter = self.__device.video_last_image_counter
        while self.alive_:
	    time.sleep(THREAD_DELAY_SEC)
	    try:
                if self.paused_ or self.__device.video_last_image_counter == tango_last_img_counter:
                    continue
                tango_last_img_counter = self.__device.video_last_image_counter
                img_data = self.__device.video_last_image
                _, _, _, frame_number, width, height, _, _, _, _ = \
                    struct.unpack(TangoClient.header_format, img_data[1][:TangoClient.header_size])
                raw = img_data[1][TangoClient.header_size:]
                img = Image.frombytes(mode='RGB', size=(width, height), data=raw)
                self.__parent.mutex.acquire()
                #self.__parent.attr_image_read = numpy.array(img.getdata()).reshape(width, height, 3)
                self.__parent.attr_image_read = numpy.array(img.convert("P"))
                self.__parent.attr_image_str_read = numpy.fromstring(raw,dtype=numpy.ubyte)
	    finally:
	        if self.__parent.mutex.locked():
		    self.__parent.mutex.release()




#----- PROTECTED REGION END -----#	//	ArinaxBzoom.additionnal_import

# Device States Description
# No states for this device


class ArinaxBzoom (PyTango.LatestDeviceImpl):
    """Arinax B-Zoom TangoVideoServer proxy"""
    
    # -------- Add you global variables here --------------------------
    #----- PROTECTED REGION ID(ArinaxBzoom.global_variables) ENABLED START -----#

    #----- PROTECTED REGION END -----#	//	ArinaxBzoom.global_variables

    def __init__(self, cl, name):
        PyTango.LatestDeviceImpl.__init__(self,cl,name)
        self.debug_stream("In __init__()")
        ArinaxBzoom.init_device(self)
        #----- PROTECTED REGION ID(ArinaxBzoom.__init__) ENABLED START -----#
	self.mutex = threading.Lock()
        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.__init__
        
    def delete_device(self):
        self.debug_stream("In delete_device()")
        #----- PROTECTED REGION ID(ArinaxBzoom.delete_device) ENABLED START -----#
        self.read_thread.alive_ = False
	self.read_thread.join()
        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.delete_device

    def init_device(self):
        self.debug_stream("In init_device()")
        self.get_device_properties(self.get_device_class())
        self.attr_lima_type_read = ""
        self.attr_camera_type_read = ""
        self.attr_camera_name_read = ""
        self.attr_image_width_read = 0
        self.attr_image_height_read = 0
        self.attr_num_zoom_levels_read = 0
        self.attr_endianness_read = False
        self.attr_video_live_read = False
        self.attr_height_magnification_ratio_read = 0.0
        self.attr_width_magnification_ratio_read = 0.0
        self.attr_height_optic_center_offset_read = 0
        self.attr_width_optic_center_offset_read = 0
        self.attr_video_exposure_read = 0.0
        self.attr_video_gain_read = 0.0
        self.attr_video_mode_read = ""
        self.attr_video_last_image_read = "", ""
        self.attr_video_last_image_counter_read = 0
        self.attr_video_zoom_percent_read = 0.0
        self.attr_video_zoom_idx_read = 0
        self.attr_video_white_balance_blue_read = 0.0
        self.attr_video_white_balance_red_read = 0.0
        self.attr_video_white_balance_read = ""
        self.attr_video_scale_read = 0.0
        self.attr_video_fps_read = 0.0
        self.attr_image_acA2500_x5_width_read = 0
        self.attr_image_acA2500_x5_height_read = 0
        self.attr_video_acA2500_x5_exposure_read = 0.0
        self.attr_video_acA2500_x5_gain_read = 0.0
        self.attr_video_acA2500_x5_mode_read = ""
        self.attr_video_acA2500_x5_last_image_read = "", ""
        self.attr_video_acA2500_x5_last_image_counter_read = 0
        self.attr_video_acA2500_x5_white_balance_blue_read = 0.0
        self.attr_video_acA2500_x5_white_balance_red_read = 0.0
        self.attr_video_acA2500_x5_white_balance_read = ""
        self.attr_video_acA2500_x5_scale_read = 0.0
        self.attr_video_acA2500_x5_fps_read = 0.0
        self.attr_image_acA2440_x30_width_read = 0
        self.attr_image_acA2440_x30_height_read = 0
        self.attr_video_acA2440_x30_exposure_read = 0.0
        self.attr_video_acA2440_x30_gain_read = 0.0
        self.attr_video_acA2440_x30_mode_read = ""
        self.attr_video_acA2440_x30_last_image_read = "", ""
        self.attr_video_acA2440_x30_last_image_counter_read = 0
        self.attr_video_acA2440_x30_white_balance_blue_read = 0.0
        self.attr_video_acA2440_x30_white_balance_red_read = 0.0
        self.attr_video_acA2440_x30_white_balance_read = ""
        self.attr_video_acA2440_x30_scale_read = 0.0
        self.attr_video_acA2440_x30_fps_read = 0.0
        self.attr_image_bzoom_width_read = 0
        self.attr_image_bzoom_height_read = 0
        self.attr_video_bzoom_exposure_read = 0.0
        self.attr_video_bzoom_gain_read = 0.0
        self.attr_video_bzoom_mode_read = ""
        self.attr_video_bzoom_last_image_read = "", ""
        self.attr_video_bzoom_last_image_counter_read = 0
        self.attr_video_bzoom_white_balance_blue_read = 0.0
        self.attr_video_bzoom_white_balance_red_read = 0.0
        self.attr_video_bzoom_white_balance_read = ""
        self.attr_video_bzoom_scale_read = 0.0
        self.attr_video_bzoom_fps_read = 0.0
        self.attr_video_exposure_range_read = [0.0]
        self.attr_video_gain_range_read = [0.0]
        self.attr_video_predefined_zoom_list_read = [0.0]
        self.attr_video_zoom_list_read = [0.0]
        self.attr_camera_pixelsize_read = [0.0]
        self.attr_video_acA2500_x5_exposure_range_read = [0.0]
        self.attr_video_acA2500_x5_gain_range_read = [0.0]
        self.attr_camera_acA2500_x5_pixelsize_read = [0.0]
        self.attr_video_acA2440_x30_exposure_range_read = [0.0]
        self.attr_video_acA2440_x30_gain_range_read = [0.0]
        self.attr_camera_acA2440_x30_pixelsize_read = [0.0]
        self.attr_video_bzoom_exposure_range_read = [0.0]
        self.attr_video_bzoom_gain_range_read = [0.0]
        self.attr_camera_bzoom_pixelsize_read = [0.0]
        self.attr_image_str_read = [0]
        self.attr_image_read = [[0]]
        #----- PROTECTED REGION ID(ArinaxBzoom.init_device) ENABLED START -----#

        try:
            self.__device = PyTango.DeviceProxy(self.bzoom_tango_url)
            self.__device.ping()
	    self.read_thread = readThread(self, self.__device)
	    self.read_thread.start()
            self.set_state(PyTango.DevState.STANDBY)
        except:
            traceback.print_exc()
            self.set_state(PyTango.DevState.FAULT)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.init_device

    def always_executed_hook(self):
        self.debug_stream("In always_excuted_hook()")
        #----- PROTECTED REGION ID(ArinaxBzoom.always_executed_hook) ENABLED START -----#

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.always_executed_hook

    # -------------------------------------------------------------------------
    #    ArinaxBzoom read/write attribute methods
    # -------------------------------------------------------------------------
    
    def read_lima_type(self, attr):
        self.debug_stream("In read_lima_type()")
        #----- PROTECTED REGION ID(ArinaxBzoom.lima_type_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.lima_type_read
        
    def read_camera_type(self, attr):
        self.debug_stream("In read_camera_type()")
        #----- PROTECTED REGION ID(ArinaxBzoom.camera_type_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.camera_type_read
        
    def read_camera_name(self, attr):
        self.debug_stream("In read_camera_name()")
        #----- PROTECTED REGION ID(ArinaxBzoom.camera_name_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.camera_name_read
        
    def write_camera_name(self, attr):
        self.debug_stream("In write_camera_name()")
        data = attr.get_write_value()
        #----- PROTECTED REGION ID(ArinaxBzoom.camera_name_write) ENABLED START -----#
        self.write_remote_attr(attr.get_name(),data)
        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.camera_name_write
        
    def read_image_width(self, attr):
        self.debug_stream("In read_image_width()")
        #----- PROTECTED REGION ID(ArinaxBzoom.image_width_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.image_width_read
        
    def read_image_height(self, attr):
        self.debug_stream("In read_image_height()")
        #----- PROTECTED REGION ID(ArinaxBzoom.image_height_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.image_height_read
        
    def read_num_zoom_levels(self, attr):
        self.debug_stream("In read_num_zoom_levels()")
        #----- PROTECTED REGION ID(ArinaxBzoom.num_zoom_levels_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.num_zoom_levels_read
        
    def read_endianness(self, attr):
        self.debug_stream("In read_endianness()")
        #----- PROTECTED REGION ID(ArinaxBzoom.endianness_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.endianness_read
        
    def read_video_live(self, attr):
        self.debug_stream("In read_video_live()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_live_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_live_read
        
    def write_video_live(self, attr):
        self.debug_stream("In write_video_live()")
        data = attr.get_write_value()
        #----- PROTECTED REGION ID(ArinaxBzoom.video_live_write) ENABLED START -----#
        self.write_remote_attr(attr.get_name(),data)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_live_write
        
    def read_height_magnification_ratio(self, attr):
        self.debug_stream("In read_height_magnification_ratio()")
        #----- PROTECTED REGION ID(ArinaxBzoom.height_magnification_ratio_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.height_magnification_ratio_read
        
    def write_height_magnification_ratio(self, attr):
        self.debug_stream("In write_height_magnification_ratio()")
        data = attr.get_write_value()
        #----- PROTECTED REGION ID(ArinaxBzoom.height_magnification_ratio_write) ENABLED START -----#
        self.write_remote_attr(attr.get_name(),data)
        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.height_magnification_ratio_write
        
    def read_width_magnification_ratio(self, attr):
        self.debug_stream("In read_width_magnification_ratio()")
        #----- PROTECTED REGION ID(ArinaxBzoom.width_magnification_ratio_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.width_magnification_ratio_read
        
    def write_width_magnification_ratio(self, attr):
        self.debug_stream("In write_width_magnification_ratio()")
        data = attr.get_write_value()
        #----- PROTECTED REGION ID(ArinaxBzoom.width_magnification_ratio_write) ENABLED START -----#
        self.write_remote_attr(attr.get_name(),data)
        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.width_magnification_ratio_write
        
    def read_height_optic_center_offset(self, attr):
        self.debug_stream("In read_height_optic_center_offset()")
        #----- PROTECTED REGION ID(ArinaxBzoom.height_optic_center_offset_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.height_optic_center_offset_read
        
    def write_height_optic_center_offset(self, attr):
        self.debug_stream("In write_height_optic_center_offset()")
        data = attr.get_write_value()
        #----- PROTECTED REGION ID(ArinaxBzoom.height_optic_center_offset_write) ENABLED START -----#
        self.write_remote_attr(attr.get_name(),data)
        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.height_optic_center_offset_write
        
    def read_width_optic_center_offset(self, attr):
        self.debug_stream("In read_width_optic_center_offset()")
        #----- PROTECTED REGION ID(ArinaxBzoom.width_optic_center_offset_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.width_optic_center_offset_read
        
    def write_width_optic_center_offset(self, attr):
        self.debug_stream("In write_width_optic_center_offset()")
        data = attr.get_write_value()
        #----- PROTECTED REGION ID(ArinaxBzoom.width_optic_center_offset_write) ENABLED START -----#
        self.write_remote_attr(attr.get_name(),data)
        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.width_optic_center_offset_write
        
    def read_video_exposure(self, attr):
        self.debug_stream("In read_video_exposure()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_exposure_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_exposure_read
        
    def write_video_exposure(self, attr):
        self.debug_stream("In write_video_exposure()")
        data = attr.get_write_value()
        #----- PROTECTED REGION ID(ArinaxBzoom.video_exposure_write) ENABLED START -----#
        self.write_remote_attr(attr.get_name(),data)
        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_exposure_write
        
    def read_video_gain(self, attr):
        self.debug_stream("In read_video_gain()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_gain_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_gain_read
        
    def write_video_gain(self, attr):
        self.debug_stream("In write_video_gain()")
        data = attr.get_write_value()
        #----- PROTECTED REGION ID(ArinaxBzoom.video_gain_write) ENABLED START -----#
        self.write_remote_attr(attr.get_name(),data)
        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_gain_write
        
    def read_video_mode(self, attr):
        self.debug_stream("In read_video_mode()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_mode_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_mode_read
        
    def write_video_mode(self, attr):
        self.debug_stream("In write_video_mode()")
        data = attr.get_write_value()
        #----- PROTECTED REGION ID(ArinaxBzoom.video_mode_write) ENABLED START -----#
        self.write_remote_attr(attr.get_name(),data)
        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_mode_write
        
    def read_video_last_image(self, attr):
        self.debug_stream("In read_video_last_image()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_last_image_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_last_image_read
        
    def read_video_last_image_counter(self, attr):
        self.debug_stream("In read_video_last_image_counter()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_last_image_counter_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_last_image_counter_read
        
    def read_video_zoom_percent(self, attr):
        self.debug_stream("In read_video_zoom_percent()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_zoom_percent_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_zoom_percent_read
        
    def write_video_zoom_percent(self, attr):
        self.debug_stream("In write_video_zoom_percent()")
        data = attr.get_write_value()
        #----- PROTECTED REGION ID(ArinaxBzoom.video_zoom_percent_write) ENABLED START -----#
        self.write_remote_attr(attr.get_name(),data)
        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_zoom_percent_write
        
    def read_video_zoom_idx(self, attr):
        self.debug_stream("In read_video_zoom_idx()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_zoom_idx_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_zoom_idx_read
        
    def write_video_zoom_idx(self, attr):
        self.debug_stream("In write_video_zoom_idx()")
        data = attr.get_write_value()
        #----- PROTECTED REGION ID(ArinaxBzoom.video_zoom_idx_write) ENABLED START -----#
        self.write_remote_attr(attr.get_name(),data)
        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_zoom_idx_write
        
    def read_video_white_balance_blue(self, attr):
        self.debug_stream("In read_video_white_balance_blue()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_white_balance_blue_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_white_balance_blue_read
        
    def write_video_white_balance_blue(self, attr):
        self.debug_stream("In write_video_white_balance_blue()")
        data = attr.get_write_value()
        #----- PROTECTED REGION ID(ArinaxBzoom.video_white_balance_blue_write) ENABLED START -----#
        self.write_remote_attr(attr.get_name(),data)
        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_white_balance_blue_write
        
    def read_video_white_balance_red(self, attr):
        self.debug_stream("In read_video_white_balance_red()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_white_balance_red_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_white_balance_red_read
        
    def write_video_white_balance_red(self, attr):
        self.debug_stream("In write_video_white_balance_red()")
        data = attr.get_write_value()
        #----- PROTECTED REGION ID(ArinaxBzoom.video_white_balance_red_write) ENABLED START -----#
        self.write_remote_attr(attr.get_name(),data)
        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_white_balance_red_write
        
    def read_video_white_balance(self, attr):
        self.debug_stream("In read_video_white_balance()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_white_balance_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_white_balance_read
        
    def write_video_white_balance(self, attr):
        self.debug_stream("In write_video_white_balance()")
        data = attr.get_write_value()
        #----- PROTECTED REGION ID(ArinaxBzoom.video_white_balance_write) ENABLED START -----#
        self.write_remote_attr(attr.get_name(),data)
        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_white_balance_write
        
    def read_video_scale(self, attr):
        self.debug_stream("In read_video_scale()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_scale_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_scale_read
        
    def read_video_fps(self, attr):
        self.debug_stream("In read_video_fps()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_fps_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_fps_read
        
    def read_image_acA2500_x5_width(self, attr):
        self.debug_stream("In read_image_acA2500_x5_width()")
        #----- PROTECTED REGION ID(ArinaxBzoom.image_acA2500_x5_width_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.image_acA2500_x5_width_read
        
    def read_image_acA2500_x5_height(self, attr):
        self.debug_stream("In read_image_acA2500_x5_height()")
        #----- PROTECTED REGION ID(ArinaxBzoom.image_acA2500_x5_height_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.image_acA2500_x5_height_read
        
    def read_video_acA2500_x5_exposure(self, attr):
        self.debug_stream("In read_video_acA2500_x5_exposure()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_acA2500_x5_exposure_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_acA2500_x5_exposure_read
        
    def write_video_acA2500_x5_exposure(self, attr):
        self.debug_stream("In write_video_acA2500_x5_exposure()")
        data = attr.get_write_value()
        #----- PROTECTED REGION ID(ArinaxBzoom.video_acA2500_x5_exposure_write) ENABLED START -----#
        self.write_remote_attr(attr.get_name(),data)
        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_acA2500_x5_exposure_write
        
    def read_video_acA2500_x5_gain(self, attr):
        self.debug_stream("In read_video_acA2500_x5_gain()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_acA2500_x5_gain_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_acA2500_x5_gain_read
        
    def write_video_acA2500_x5_gain(self, attr):
        self.debug_stream("In write_video_acA2500_x5_gain()")
        data = attr.get_write_value()
        #----- PROTECTED REGION ID(ArinaxBzoom.video_acA2500_x5_gain_write) ENABLED START -----#
        self.write_remote_attr(attr.get_name(),data)
        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_acA2500_x5_gain_write
        
    def read_video_acA2500_x5_mode(self, attr):
        self.debug_stream("In read_video_acA2500_x5_mode()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_acA2500_x5_mode_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_acA2500_x5_mode_read
        
    def write_video_acA2500_x5_mode(self, attr):
        self.debug_stream("In write_video_acA2500_x5_mode()")
        data = attr.get_write_value()
        #----- PROTECTED REGION ID(ArinaxBzoom.video_acA2500_x5_mode_write) ENABLED START -----#
        self.write_remote_attr(attr.get_name(),data)
        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_acA2500_x5_mode_write
        
    def read_video_acA2500_x5_last_image(self, attr):
        self.debug_stream("In read_video_acA2500_x5_last_image()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_acA2500_x5_last_image_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_acA2500_x5_last_image_read
        
    def read_video_acA2500_x5_last_image_counter(self, attr):
        self.debug_stream("In read_video_acA2500_x5_last_image_counter()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_acA2500_x5_last_image_counter_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_acA2500_x5_last_image_counter_read
        
    def read_video_acA2500_x5_white_balance_blue(self, attr):
        self.debug_stream("In read_video_acA2500_x5_white_balance_blue()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_acA2500_x5_white_balance_blue_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_acA2500_x5_white_balance_blue_read
        
    def write_video_acA2500_x5_white_balance_blue(self, attr):
        self.debug_stream("In write_video_acA2500_x5_white_balance_blue()")
        data = attr.get_write_value()
        #----- PROTECTED REGION ID(ArinaxBzoom.video_acA2500_x5_white_balance_blue_write) ENABLED START -----#
        self.write_remote_attr(attr.get_name(),data)
        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_acA2500_x5_white_balance_blue_write
        
    def read_video_acA2500_x5_white_balance_red(self, attr):
        self.debug_stream("In read_video_acA2500_x5_white_balance_red()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_acA2500_x5_white_balance_red_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_acA2500_x5_white_balance_red_read
        
    def write_video_acA2500_x5_white_balance_red(self, attr):
        self.debug_stream("In write_video_acA2500_x5_white_balance_red()")
        data = attr.get_write_value()
        #----- PROTECTED REGION ID(ArinaxBzoom.video_acA2500_x5_white_balance_red_write) ENABLED START -----#
        self.write_remote_attr(attr.get_name(),data)
        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_acA2500_x5_white_balance_red_write
        
    def read_video_acA2500_x5_white_balance(self, attr):
        self.debug_stream("In read_video_acA2500_x5_white_balance()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_acA2500_x5_white_balance_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_acA2500_x5_white_balance_read
        
    def write_video_acA2500_x5_white_balance(self, attr):
        self.debug_stream("In write_video_acA2500_x5_white_balance()")
        data = attr.get_write_value()
        #----- PROTECTED REGION ID(ArinaxBzoom.video_acA2500_x5_white_balance_write) ENABLED START -----#
        self.write_remote_attr(attr.get_name(),data)
        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_acA2500_x5_white_balance_write
        
    def read_video_acA2500_x5_scale(self, attr):
        self.debug_stream("In read_video_acA2500_x5_scale()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_acA2500_x5_scale_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_acA2500_x5_scale_read
        
    def read_video_acA2500_x5_fps(self, attr):
        self.debug_stream("In read_video_acA2500_x5_fps()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_acA2500_x5_fps_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_acA2500_x5_fps_read
        
    def read_image_acA2440_x30_width(self, attr):
        self.debug_stream("In read_image_acA2440_x30_width()")
        #----- PROTECTED REGION ID(ArinaxBzoom.image_acA2440_x30_width_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.image_acA2440_x30_width_read
        
    def read_image_acA2440_x30_height(self, attr):
        self.debug_stream("In read_image_acA2440_x30_height()")
        #----- PROTECTED REGION ID(ArinaxBzoom.image_acA2440_x30_height_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.image_acA2440_x30_height_read
        
    def read_video_acA2440_x30_exposure(self, attr):
        self.debug_stream("In read_video_acA2440_x30_exposure()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_acA2440_x30_exposure_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_acA2440_x30_exposure_read
        
    def write_video_acA2440_x30_exposure(self, attr):
        self.debug_stream("In write_video_acA2440_x30_exposure()")
        data = attr.get_write_value()
        #----- PROTECTED REGION ID(ArinaxBzoom.video_acA2440_x30_exposure_write) ENABLED START -----#
        self.write_remote_attr(attr.get_name(),data)
        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_acA2440_x30_exposure_write
        
    def read_video_acA2440_x30_gain(self, attr):
        self.debug_stream("In read_video_acA2440_x30_gain()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_acA2440_x30_gain_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_acA2440_x30_gain_read
        
    def write_video_acA2440_x30_gain(self, attr):
        self.debug_stream("In write_video_acA2440_x30_gain()")
        data = attr.get_write_value()
        #----- PROTECTED REGION ID(ArinaxBzoom.video_acA2440_x30_gain_write) ENABLED START -----#
        self.write_remote_attr(attr.get_name(),data)
        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_acA2440_x30_gain_write
        
    def read_video_acA2440_x30_mode(self, attr):
        self.debug_stream("In read_video_acA2440_x30_mode()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_acA2440_x30_mode_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_acA2440_x30_mode_read
        
    def write_video_acA2440_x30_mode(self, attr):
        self.debug_stream("In write_video_acA2440_x30_mode()")
        data = attr.get_write_value()
        #----- PROTECTED REGION ID(ArinaxBzoom.video_acA2440_x30_mode_write) ENABLED START -----#
        self.write_remote_attr(attr.get_name(),data)
        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_acA2440_x30_mode_write
        
    def read_video_acA2440_x30_last_image(self, attr):
        self.debug_stream("In read_video_acA2440_x30_last_image()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_acA2440_x30_last_image_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_acA2440_x30_last_image_read
        
    def read_video_acA2440_x30_last_image_counter(self, attr):
        self.debug_stream("In read_video_acA2440_x30_last_image_counter()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_acA2440_x30_last_image_counter_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_acA2440_x30_last_image_counter_read
        
    def read_video_acA2440_x30_white_balance_blue(self, attr):
        self.debug_stream("In read_video_acA2440_x30_white_balance_blue()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_acA2440_x30_white_balance_blue_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_acA2440_x30_white_balance_blue_read
        
    def write_video_acA2440_x30_white_balance_blue(self, attr):
        self.debug_stream("In write_video_acA2440_x30_white_balance_blue()")
        data = attr.get_write_value()
        #----- PROTECTED REGION ID(ArinaxBzoom.video_acA2440_x30_white_balance_blue_write) ENABLED START -----#
        self.write_remote_attr(attr.get_name(),data)
        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_acA2440_x30_white_balance_blue_write
        
    def read_video_acA2440_x30_white_balance_red(self, attr):
        self.debug_stream("In read_video_acA2440_x30_white_balance_red()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_acA2440_x30_white_balance_red_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_acA2440_x30_white_balance_red_read
        
    def write_video_acA2440_x30_white_balance_red(self, attr):
        self.debug_stream("In write_video_acA2440_x30_white_balance_red()")
        data = attr.get_write_value()
        #----- PROTECTED REGION ID(ArinaxBzoom.video_acA2440_x30_white_balance_red_write) ENABLED START -----#
        self.write_remote_attr(attr.get_name(),data)
        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_acA2440_x30_white_balance_red_write
        
    def read_video_acA2440_x30_white_balance(self, attr):
        self.debug_stream("In read_video_acA2440_x30_white_balance()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_acA2440_x30_white_balance_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_acA2440_x30_white_balance_read
        
    def write_video_acA2440_x30_white_balance(self, attr):
        self.debug_stream("In write_video_acA2440_x30_white_balance()")
        data = attr.get_write_value()
        #----- PROTECTED REGION ID(ArinaxBzoom.video_acA2440_x30_white_balance_write) ENABLED START -----#
        self.write_remote_attr(attr.get_name(),data)
        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_acA2440_x30_white_balance_write
        
    def read_video_acA2440_x30_scale(self, attr):
        self.debug_stream("In read_video_acA2440_x30_scale()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_acA2440_x30_scale_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_acA2440_x30_scale_read
        
    def read_video_acA2440_x30_fps(self, attr):
        self.debug_stream("In read_video_acA2440_x30_fps()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_acA2440_x30_fps_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_acA2440_x30_fps_read
        
    def read_image_bzoom_width(self, attr):
        self.debug_stream("In read_image_bzoom_width()")
        #----- PROTECTED REGION ID(ArinaxBzoom.image_bzoom_width_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.image_bzoom_width_read
        
    def read_image_bzoom_height(self, attr):
        self.debug_stream("In read_image_bzoom_height()")
        #----- PROTECTED REGION ID(ArinaxBzoom.image_bzoom_height_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.image_bzoom_height_read
        
    def read_video_bzoom_exposure(self, attr):
        self.debug_stream("In read_video_bzoom_exposure()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_bzoom_exposure_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_bzoom_exposure_read
        
    def write_video_bzoom_exposure(self, attr):
        self.debug_stream("In write_video_bzoom_exposure()")
        data = attr.get_write_value()
        #----- PROTECTED REGION ID(ArinaxBzoom.video_bzoom_exposure_write) ENABLED START -----#
        self.write_remote_attr(attr.get_name(),data)
        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_bzoom_exposure_write
        
    def read_video_bzoom_gain(self, attr):
        self.debug_stream("In read_video_bzoom_gain()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_bzoom_gain_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_bzoom_gain_read
        
    def write_video_bzoom_gain(self, attr):
        self.debug_stream("In write_video_bzoom_gain()")
        data = attr.get_write_value()
        #----- PROTECTED REGION ID(ArinaxBzoom.video_bzoom_gain_write) ENABLED START -----#
        self.write_remote_attr(attr.get_name(),data)
        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_bzoom_gain_write
        
    def read_video_bzoom_mode(self, attr):
        self.debug_stream("In read_video_bzoom_mode()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_bzoom_mode_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_bzoom_mode_read
        
    def write_video_bzoom_mode(self, attr):
        self.debug_stream("In write_video_bzoom_mode()")
        data = attr.get_write_value()
        #----- PROTECTED REGION ID(ArinaxBzoom.video_bzoom_mode_write) ENABLED START -----#
        self.write_remote_attr(attr.get_name(),data)
        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_bzoom_mode_write
        
    def read_video_bzoom_last_image(self, attr):
        self.debug_stream("In read_video_bzoom_last_image()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_bzoom_last_image_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_bzoom_last_image_read
        
    def read_video_bzoom_last_image_counter(self, attr):
        self.debug_stream("In read_video_bzoom_last_image_counter()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_bzoom_last_image_counter_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_bzoom_last_image_counter_read
        
    def read_video_bzoom_white_balance_blue(self, attr):
        self.debug_stream("In read_video_bzoom_white_balance_blue()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_bzoom_white_balance_blue_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_bzoom_white_balance_blue_read
        
    def write_video_bzoom_white_balance_blue(self, attr):
        self.debug_stream("In write_video_bzoom_white_balance_blue()")
        data = attr.get_write_value()
        #----- PROTECTED REGION ID(ArinaxBzoom.video_bzoom_white_balance_blue_write) ENABLED START -----#
        self.write_remote_attr(attr.get_name(),data)
        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_bzoom_white_balance_blue_write
        
    def read_video_bzoom_white_balance_red(self, attr):
        self.debug_stream("In read_video_bzoom_white_balance_red()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_bzoom_white_balance_red_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_bzoom_white_balance_red_read
        
    def write_video_bzoom_white_balance_red(self, attr):
        self.debug_stream("In write_video_bzoom_white_balance_red()")
        data = attr.get_write_value()
        #----- PROTECTED REGION ID(ArinaxBzoom.video_bzoom_white_balance_red_write) ENABLED START -----#
        self.write_remote_attr(attr.get_name(),data)
        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_bzoom_white_balance_red_write
        
    def read_video_bzoom_white_balance(self, attr):
        self.debug_stream("In read_video_bzoom_white_balance()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_bzoom_white_balance_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_bzoom_white_balance_read
        
    def write_video_bzoom_white_balance(self, attr):
        self.debug_stream("In write_video_bzoom_white_balance()")
        data = attr.get_write_value()
        #----- PROTECTED REGION ID(ArinaxBzoom.video_bzoom_white_balance_write) ENABLED START -----#
        self.write_remote_attr(attr.get_name(),data)
        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_bzoom_white_balance_write
        
    def read_video_bzoom_scale(self, attr):
        self.debug_stream("In read_video_bzoom_scale()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_bzoom_scale_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_bzoom_scale_read
        
    def read_video_bzoom_fps(self, attr):
        self.debug_stream("In read_video_bzoom_fps()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_bzoom_fps_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_bzoom_fps_read
        
    def read_video_exposure_range(self, attr):
        self.debug_stream("In read_video_exposure_range()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_exposure_range_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_exposure_range_read
        
    def read_video_gain_range(self, attr):
        self.debug_stream("In read_video_gain_range()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_gain_range_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_gain_range_read
        
    def read_video_predefined_zoom_list(self, attr):
        self.debug_stream("In read_video_predefined_zoom_list()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_predefined_zoom_list_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_predefined_zoom_list_read
        
    def read_video_zoom_list(self, attr):
        self.debug_stream("In read_video_zoom_list()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_zoom_list_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_zoom_list_read
        
    def read_camera_pixelsize(self, attr):
        self.debug_stream("In read_camera_pixelsize()")
        #----- PROTECTED REGION ID(ArinaxBzoom.camera_pixelsize_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.camera_pixelsize_read
        
    def read_video_acA2500_x5_exposure_range(self, attr):
        self.debug_stream("In read_video_acA2500_x5_exposure_range()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_acA2500_x5_exposure_range_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_acA2500_x5_exposure_range_read
        
    def read_video_acA2500_x5_gain_range(self, attr):
        self.debug_stream("In read_video_acA2500_x5_gain_range()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_acA2500_x5_gain_range_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_acA2500_x5_gain_range_read
        
    def read_camera_acA2500_x5_pixelsize(self, attr):
        self.debug_stream("In read_camera_acA2500_x5_pixelsize()")
        #----- PROTECTED REGION ID(ArinaxBzoom.camera_acA2500_x5_pixelsize_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.camera_acA2500_x5_pixelsize_read
        
    def read_video_acA2440_x30_exposure_range(self, attr):
        self.debug_stream("In read_video_acA2440_x30_exposure_range()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_acA2440_x30_exposure_range_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_acA2440_x30_exposure_range_read
        
    def read_video_acA2440_x30_gain_range(self, attr):
        self.debug_stream("In read_video_acA2440_x30_gain_range()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_acA2440_x30_gain_range_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_acA2440_x30_gain_range_read
        
    def read_camera_acA2440_x30_pixelsize(self, attr):
        self.debug_stream("In read_camera_acA2440_x30_pixelsize()")
        #----- PROTECTED REGION ID(ArinaxBzoom.camera_acA2440_x30_pixelsize_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.camera_acA2440_x30_pixelsize_read
        
    def read_video_bzoom_exposure_range(self, attr):
        self.debug_stream("In read_video_bzoom_exposure_range()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_bzoom_exposure_range_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_bzoom_exposure_range_read
        
    def read_video_bzoom_gain_range(self, attr):
        self.debug_stream("In read_video_bzoom_gain_range()")
        #----- PROTECTED REGION ID(ArinaxBzoom.video_bzoom_gain_range_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.video_bzoom_gain_range_read
        
    def read_camera_bzoom_pixelsize(self, attr):
        self.debug_stream("In read_camera_bzoom_pixelsize()")
        #----- PROTECTED REGION ID(ArinaxBzoom.camera_bzoom_pixelsize_read) ENABLED START -----#
	attr_value = self.read_remote_attr(attr.get_name())
        attr.set_value(attr_value)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.camera_bzoom_pixelsize_read
        
    def read_image_str(self, attr):
        self.debug_stream("In read_image_str()")
        #----- PROTECTED REGION ID(ArinaxBzoom.image_str_read) ENABLED START -----#
        attr.set_value(self.attr_image_str_read)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.image_str_read
        
    def read_image(self, attr):
        self.debug_stream("In read_image()")
        #----- PROTECTED REGION ID(ArinaxBzoom.image_read) ENABLED START -----#
        attr.set_value(self.attr_image_read)

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.image_read
        
    
    
            
    def read_attr_hardware(self, data):
        self.debug_stream("In read_attr_hardware()")
        #----- PROTECTED REGION ID(ArinaxBzoom.read_attr_hardware) ENABLED START -----#

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.read_attr_hardware


    # -------------------------------------------------------------------------
    #    ArinaxBzoom command methods
    # -------------------------------------------------------------------------
    
    def getAttrStringValueList(self, argin):
        """ 
        :param argin: Attribute name
        :type argin: PyTango.DevString
        :return: Authorized String value list
        :rtype: PyTango.DevVarStringArray
        """
        self.debug_stream("In getAttrStringValueList()")
        argout = [""]
        #----- PROTECTED REGION ID(ArinaxBzoom.getAttrStringValueList) ENABLED START -----#
        try:
	    self.mutex.acquire()
	    argout = self.__device.getAttrStringValueList(argin)
	except Exception, e:
	    self.mutex.release()
	    raise e
	if self.mutex.locked():
	    self.mutex.release()

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.getAttrStringValueList
        return argout
        
    def Start(self):
        """ 
        """
        self.debug_stream("In Start()")
        #----- PROTECTED REGION ID(ArinaxBzoom.Start) ENABLED START -----#
        if self.get_state() != PyTango.DevState.FAULT:
            self.read_thread.paused_ = False
            self.set_state(PyTango.DevState.ON)
        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.Start
        
    def Stop(self):
        """ 
        """
        self.debug_stream("In Stop()")
        #----- PROTECTED REGION ID(ArinaxBzoom.Stop) ENABLED START -----#
        if self.get_state() != PyTango.DevState.FAULT:
            self.read_thread.paused_ = True
            self.set_state(PyTango.DevState.STANDBY)
        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.Stop
        

    #----- PROTECTED REGION ID(ArinaxBzoom.programmer_methods) ENABLED START -----#

    def read_remote_attr(self, name):
        self.debug_stream("In read_remote_attr()")
        try:
	    self.mutex.acquire()
	    attr = self.__device.read_attribute(name.replace("_x","-x"))
	except Exception, e:
	    self.mutex.release()
	    raise e
	if self.mutex.locked():
	    self.mutex.release()
	return attr.value

    def write_remote_attr(self, name, value):
        self.debug_stream("In write_remote_attr()")
        try:
	    self.mutex.acquire()
	    attr = self.__device.write_attribute(name.replace("_x","-x"),value)
	except Exception, e:
	    self.mutex.release()
	    raise e
	if self.mutex.locked():
	    self.mutex.release()

    #----- PROTECTED REGION END -----#	//	ArinaxBzoom.programmer_methods

class ArinaxBzoomClass(PyTango.DeviceClass):
    # -------- Add you global class variables here --------------------------
    #----- PROTECTED REGION ID(ArinaxBzoom.global_class_variables) ENABLED START -----#

    #----- PROTECTED REGION END -----#	//	ArinaxBzoom.global_class_variables


    #    Class Properties
    class_property_list = {
        }


    #    Device Properties
    device_property_list = {
        'bzoom_tango_url':
            [PyTango.DevString, 
             '',
            [] ],
        }


    #    Command definitions
    cmd_list = {
        'getAttrStringValueList':
            [[PyTango.DevString, "Attribute name"],
            [PyTango.DevVarStringArray, "Authorized String value list"]],
        'Start':
            [[PyTango.DevVoid, "none"],
            [PyTango.DevVoid, "none"]],
        'Stop':
            [[PyTango.DevVoid, "none"],
            [PyTango.DevVoid, "none"]],
        }


    #    Attribute definitions
    attr_list = {
        'lima_type':
            [[PyTango.DevString,
            PyTango.SCALAR,
            PyTango.READ],
            {
                'label': "lima_type",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%s",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'camera_type':
            [[PyTango.DevString,
            PyTango.SCALAR,
            PyTango.READ],
            {
                'label': "camera_type",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%s",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'camera_name':
            [[PyTango.DevString,
            PyTango.SCALAR,
            PyTango.READ_WRITE],
            {
                'label': "camera_name",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%s",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'image_width':
            [[PyTango.DevULong64,
            PyTango.SCALAR,
            PyTango.READ],
            {
                'label': "image_width",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%d",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'image_height':
            [[PyTango.DevULong64,
            PyTango.SCALAR,
            PyTango.READ],
            {
                'label': "image_height",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%d",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'num_zoom_levels':
            [[PyTango.DevUShort,
            PyTango.SCALAR,
            PyTango.READ],
            {
                'label': "num_zoom_levels",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%d",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'endianness':
            [[PyTango.DevBoolean,
            PyTango.SCALAR,
            PyTango.READ],
            {
                'label': "endianness",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "Not specified",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_live':
            [[PyTango.DevBoolean,
            PyTango.SCALAR,
            PyTango.READ_WRITE],
            {
                'label': "video_live",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "Not specified",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'height_magnification_ratio':
            [[PyTango.DevDouble,
            PyTango.SCALAR,
            PyTango.READ_WRITE],
            {
                'label': "height_magnification_ratio",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%6.2f",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'width_magnification_ratio':
            [[PyTango.DevDouble,
            PyTango.SCALAR,
            PyTango.READ_WRITE],
            {
                'label': "width_magnification_ratio",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%6.2f",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'height_optic_center_offset':
            [[PyTango.DevLong64,
            PyTango.SCALAR,
            PyTango.READ_WRITE],
            {
                'label': "height_optic_center_offset",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%d",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'width_optic_center_offset':
            [[PyTango.DevLong64,
            PyTango.SCALAR,
            PyTango.READ_WRITE],
            {
                'label': "width_optic_center_offset",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%d",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_exposure':
            [[PyTango.DevDouble,
            PyTango.SCALAR,
            PyTango.READ_WRITE],
            {
                'label': "video_exposure",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%6.2f",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_gain':
            [[PyTango.DevDouble,
            PyTango.SCALAR,
            PyTango.READ_WRITE],
            {
                'label': "video_gain",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%6.2f",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_mode':
            [[PyTango.DevString,
            PyTango.SCALAR,
            PyTango.READ_WRITE],
            {
                'label': "video_mode",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%s",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_last_image':
            [[PyTango.DevEncoded,
            PyTango.SCALAR,
            PyTango.READ],
            {
                'label': "the video image",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%d",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "video image as encoded",
            } ],
        'video_last_image_counter':
            [[PyTango.DevLong64,
            PyTango.SCALAR,
            PyTango.READ],
            {
                'label': "video_last_image_counter",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%d",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_zoom_percent':
            [[PyTango.DevDouble,
            PyTango.SCALAR,
            PyTango.READ_WRITE],
            {
                'label': "video_zoom_percent",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%6.2f",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_zoom_idx':
            [[PyTango.DevShort,
            PyTango.SCALAR,
            PyTango.READ_WRITE],
            {
                'label': "video_zoom_idx",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%d",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_white_balance_blue':
            [[PyTango.DevDouble,
            PyTango.SCALAR,
            PyTango.READ_WRITE],
            {
                'label': "video_white_balance_blue",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%6.2f",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_white_balance_red':
            [[PyTango.DevDouble,
            PyTango.SCALAR,
            PyTango.READ_WRITE],
            {
                'label': "video_white_balance_red",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%6.2f",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_white_balance':
            [[PyTango.DevString,
            PyTango.SCALAR,
            PyTango.READ_WRITE],
            {
                'label': "video_white_balance",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%s",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_scale':
            [[PyTango.DevDouble,
            PyTango.SCALAR,
            PyTango.READ],
            {
                'label': "video_scale",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%6.2f",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_fps':
            [[PyTango.DevDouble,
            PyTango.SCALAR,
            PyTango.READ],
            {
                'label': "video_fps",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%6.2f",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'image_acA2500_x5_width':
            [[PyTango.DevULong64,
            PyTango.SCALAR,
            PyTango.READ],
            {
                'label': "image_acA2500_x5_width",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%d",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'image_acA2500_x5_height':
            [[PyTango.DevULong64,
            PyTango.SCALAR,
            PyTango.READ],
            {
                'label': "image_acA2500_x5_height",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%d",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_acA2500_x5_exposure':
            [[PyTango.DevDouble,
            PyTango.SCALAR,
            PyTango.READ_WRITE],
            {
                'label': "video_acA2500_x5_exposure",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%6.2f",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_acA2500_x5_gain':
            [[PyTango.DevDouble,
            PyTango.SCALAR,
            PyTango.READ_WRITE],
            {
                'label': "video_acA2500_x5_gain",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%6.2f",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_acA2500_x5_mode':
            [[PyTango.DevString,
            PyTango.SCALAR,
            PyTango.READ_WRITE],
            {
                'label': "video_acA2500_x5_mode",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%s",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_acA2500_x5_last_image':
            [[PyTango.DevEncoded,
            PyTango.SCALAR,
            PyTango.READ],
            {
                'label': "the video image",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%d",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "video image as encoded",
            } ],
        'video_acA2500_x5_last_image_counter':
            [[PyTango.DevLong64,
            PyTango.SCALAR,
            PyTango.READ],
            {
                'label': "video_acA2500_x5_last_image_counter",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%d",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_acA2500_x5_white_balance_blue':
            [[PyTango.DevDouble,
            PyTango.SCALAR,
            PyTango.READ_WRITE],
            {
                'label': "video_acA2500_x5_white_balance_blue",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%6.2f",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_acA2500_x5_white_balance_red':
            [[PyTango.DevDouble,
            PyTango.SCALAR,
            PyTango.READ_WRITE],
            {
                'label': "video_acA2500_x5_white_balance_red",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%6.2f",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_acA2500_x5_white_balance':
            [[PyTango.DevString,
            PyTango.SCALAR,
            PyTango.READ_WRITE],
            {
                'label': "video_acA2500_x5_white_balance",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%s",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_acA2500_x5_scale':
            [[PyTango.DevDouble,
            PyTango.SCALAR,
            PyTango.READ],
            {
                'label': "video_acA2500_x5_scale",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%6.2f",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_acA2500_x5_fps':
            [[PyTango.DevDouble,
            PyTango.SCALAR,
            PyTango.READ],
            {
                'label': "video_acA2500_x5_fps",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%6.2f",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'image_acA2440_x30_width':
            [[PyTango.DevULong64,
            PyTango.SCALAR,
            PyTango.READ],
            {
                'label': "image_acA2440_x30_width",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%d",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'image_acA2440_x30_height':
            [[PyTango.DevULong64,
            PyTango.SCALAR,
            PyTango.READ],
            {
                'label': "image_acA2440_x30_height",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%d",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_acA2440_x30_exposure':
            [[PyTango.DevDouble,
            PyTango.SCALAR,
            PyTango.READ_WRITE],
            {
                'label': "video_acA2440_x30_exposure",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%6.2f",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_acA2440_x30_gain':
            [[PyTango.DevDouble,
            PyTango.SCALAR,
            PyTango.READ_WRITE],
            {
                'label': "video_acA2440_x30_gain",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%6.2f",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_acA2440_x30_mode':
            [[PyTango.DevString,
            PyTango.SCALAR,
            PyTango.READ_WRITE],
            {
                'label': "video_acA2440_x30_mode",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%s",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_acA2440_x30_last_image':
            [[PyTango.DevEncoded,
            PyTango.SCALAR,
            PyTango.READ],
            {
                'label': "the video image",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%d",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "video image as encoded",
            } ],
        'video_acA2440_x30_last_image_counter':
            [[PyTango.DevLong64,
            PyTango.SCALAR,
            PyTango.READ],
            {
                'label': "video_acA2440_x30_last_image_counter",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%d",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_acA2440_x30_white_balance_blue':
            [[PyTango.DevDouble,
            PyTango.SCALAR,
            PyTango.READ_WRITE],
            {
                'label': "video_acA2440_x30_white_balance_blue",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%6.2f",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_acA2440_x30_white_balance_red':
            [[PyTango.DevDouble,
            PyTango.SCALAR,
            PyTango.READ_WRITE],
            {
                'label': "video_acA2440_x30_white_balance_red",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%6.2f",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_acA2440_x30_white_balance':
            [[PyTango.DevString,
            PyTango.SCALAR,
            PyTango.READ_WRITE],
            {
                'label': "video_acA2440_x30_white_balance",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%s",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_acA2440_x30_scale':
            [[PyTango.DevDouble,
            PyTango.SCALAR,
            PyTango.READ],
            {
                'label': "video_acA2440_x30_scale",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%6.2f",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_acA2440_x30_fps':
            [[PyTango.DevDouble,
            PyTango.SCALAR,
            PyTango.READ],
            {
                'label': "video_acA2440_x30_fps",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%6.2f",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'image_bzoom_width':
            [[PyTango.DevULong64,
            PyTango.SCALAR,
            PyTango.READ],
            {
                'label': "image_bzoom_width",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%d",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'image_bzoom_height':
            [[PyTango.DevULong64,
            PyTango.SCALAR,
            PyTango.READ],
            {
                'label': "image_bzoom_height",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%d",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_bzoom_exposure':
            [[PyTango.DevDouble,
            PyTango.SCALAR,
            PyTango.READ_WRITE],
            {
                'label': "video_bzoom_exposure",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%6.2f",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_bzoom_gain':
            [[PyTango.DevDouble,
            PyTango.SCALAR,
            PyTango.READ_WRITE],
            {
                'label': "video_bzoom_gain",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%6.2f",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_bzoom_mode':
            [[PyTango.DevString,
            PyTango.SCALAR,
            PyTango.READ_WRITE],
            {
                'label': "video_bzoom_mode",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%s",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_bzoom_last_image':
            [[PyTango.DevEncoded,
            PyTango.SCALAR,
            PyTango.READ],
            {
                'label': "the video image",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%d",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "video image as encoded",
            } ],
        'video_bzoom_last_image_counter':
            [[PyTango.DevLong64,
            PyTango.SCALAR,
            PyTango.READ],
            {
                'label': "video_bzoom_last_image_counter",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%d",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_bzoom_white_balance_blue':
            [[PyTango.DevDouble,
            PyTango.SCALAR,
            PyTango.READ_WRITE],
            {
                'label': "video_bzoom_white_balance_blue",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%6.2f",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_bzoom_white_balance_red':
            [[PyTango.DevDouble,
            PyTango.SCALAR,
            PyTango.READ_WRITE],
            {
                'label': "video_bzoom_white_balance_red",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%6.2f",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_bzoom_white_balance':
            [[PyTango.DevString,
            PyTango.SCALAR,
            PyTango.READ_WRITE],
            {
                'label': "video_bzoom_white_balance",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%s",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_bzoom_scale':
            [[PyTango.DevDouble,
            PyTango.SCALAR,
            PyTango.READ],
            {
                'label': "video_bzoom_scale",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%6.2f",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_bzoom_fps':
            [[PyTango.DevDouble,
            PyTango.SCALAR,
            PyTango.READ],
            {
                'label': "video_bzoom_fps",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%6.2f",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_exposure_range':
            [[PyTango.DevDouble,
            PyTango.SPECTRUM,
            PyTango.READ, 2],
            {
                'label': "video_exposure_range",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%6.2f",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_gain_range':
            [[PyTango.DevDouble,
            PyTango.SPECTRUM,
            PyTango.READ, 2],
            {
                'label': "video_gain_range",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%6.2f",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_predefined_zoom_list':
            [[PyTango.DevDouble,
            PyTango.SPECTRUM,
            PyTango.READ, 4],
            {
                'label': "video_predefined_zoom_list",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%6.2f",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_zoom_list':
            [[PyTango.DevDouble,
            PyTango.SPECTRUM,
            PyTango.READ, 4],
            {
                'label': "video_zoom_list",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%6.2f",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'camera_pixelsize':
            [[PyTango.DevDouble,
            PyTango.SPECTRUM,
            PyTango.READ, 2],
            {
                'label': "Pixel size:x_size, y_size",
                'unit': "meter",
                'standard unit': "meter",
                'display unit': "meter",
                'format': "%f",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "Size of the pixel in meter",
            } ],
        'video_acA2500_x5_exposure_range':
            [[PyTango.DevDouble,
            PyTango.SPECTRUM,
            PyTango.READ, 2],
            {
                'label': "video_acA2500_x5_exposure_range",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%6.2f",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_acA2500_x5_gain_range':
            [[PyTango.DevDouble,
            PyTango.SPECTRUM,
            PyTango.READ, 2],
            {
                'label': "video_acA2500_x5_gain_range",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%6.2f",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'camera_acA2500_x5_pixelsize':
            [[PyTango.DevDouble,
            PyTango.SPECTRUM,
            PyTango.READ, 2],
            {
                'label': "Pixel size:x_size, y_size",
                'unit': "meter",
                'standard unit': "meter",
                'display unit': "meter",
                'format': "%f",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "Size of the pixel in meter",
            } ],
        'video_acA2440_x30_exposure_range':
            [[PyTango.DevDouble,
            PyTango.SPECTRUM,
            PyTango.READ, 2],
            {
                'label': "video_acA2440_x30_exposure_range",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%6.2f",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_acA2440_x30_gain_range':
            [[PyTango.DevDouble,
            PyTango.SPECTRUM,
            PyTango.READ, 2],
            {
                'label': "video_acA2440_x30_gain_range",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%6.2f",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'camera_acA2440_x30_pixelsize':
            [[PyTango.DevDouble,
            PyTango.SPECTRUM,
            PyTango.READ, 2],
            {
                'label': "Pixel size:x_size, y_size",
                'unit': "meter",
                'standard unit': "meter",
                'display unit': "meter",
                'format': "%f",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "Size of the pixel in meter",
            } ],
        'video_bzoom_exposure_range':
            [[PyTango.DevDouble,
            PyTango.SPECTRUM,
            PyTango.READ, 2],
            {
                'label': "video_bzoom_exposure_range",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%6.2f",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'video_bzoom_gain_range':
            [[PyTango.DevDouble,
            PyTango.SPECTRUM,
            PyTango.READ, 2],
            {
                'label': "video_bzoom_gain_range",
                'standard unit': "No standard unit",
                'display unit': "No display unit",
                'format': "%6.2f",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "No description",
            } ],
        'camera_bzoom_pixelsize':
            [[PyTango.DevDouble,
            PyTango.SPECTRUM,
            PyTango.READ, 2],
            {
                'label': "Pixel size:x_size, y_size",
                'unit': "meter",
                'standard unit': "meter",
                'display unit': "meter",
                'format': "%f",
                'max value': "Not specified",
                'min value': "Not specified",
                'max alarm': "Not specified",
                'min alarm': "Not specified",
                'description': "Size of the pixel in meter",
            } ],
        'image_str':
            [[PyTango.DevUChar,
            PyTango.SPECTRUM,
            PyTango.READ, 10000000]],
        'image':
            [[PyTango.DevLong,
            PyTango.IMAGE,
            PyTango.READ, 3000, 3000]],
        }


def main():
    try:
        py = PyTango.Util(sys.argv)
        py.add_class(ArinaxBzoomClass, ArinaxBzoom, 'ArinaxBzoom')
        #----- PROTECTED REGION ID(ArinaxBzoom.add_classes) ENABLED START -----#

        #----- PROTECTED REGION END -----#	//	ArinaxBzoom.add_classes

        U = PyTango.Util.instance()
        U.server_init()
        U.server_run()

    except PyTango.DevFailed as e:
        print ('-------> Received a DevFailed exception:', e)
    except Exception as e:
        print ('-------> An unforeseen exception occured....', e)

if __name__ == '__main__':
    main()
